This function adjusts a list of indices after certain indices have been removed. The new indices will point to the same elements as the original indices. If an index is removed, it will also be removed from the indices list.
adjust_indices_after_remove(indicesList, removedIndices)A list of adjusted indices. Each set of indices is adjusted separately.
A list of integer vectors, each representing a set of indices.
A vector of integers representing the indices to be removed.