This function extracts coefficient matrix from an ldt.estim object.
# S3 method for ldt.estim
coef(object, equations = NULL, removeZeroRest = FALSE, ...)If zero restrictions are not removed, it is a matrix containing the coefficients of the system. Each column of the matrix belongs to an equation. Explanatory variables are in the rows. Otherwise, coefficients of different equations are reported in a list.
An object of class ldt.estim
A number, a numeric array or a string array specifying the indices or names of the endogenous variables in the equations.
NULL means all equations.
If TRUE and model is restricted, zero restrictions are removed.
Additional arguments.