Use this function to get the required options when Nelder-Mead optimization is needed such as s.gld.from.moments function.
get.options.neldermead(
maxIterations = 100,
tolerance = 1e-06,
reflection = 1,
expansion = 2,
contraction = 0.5,
shrink = 1
)A list with the given options.
(int) Maximum number of iterations.
A small number to determine the convergence. The algorithm terminates when the difference between the best and worst points in the simplex is less than this value.
A number for reflection coefficient. It controls how far the worst point is reflected through the centroid of the remaining points.
A number that determines the expansion coefficient. It controls how far the reflected point is expanded along the line connecting it to the centroid.
A number that determines the contraction coefficient. It controls how far the worst point is contracted towards the centroid.
A number that determines the shrink coefficient. It controls how much the simplex is shrunk towards the best point when all other moves are rejected.