Learn R Programming

ldt (version 0.5.3)

get.options.newton: Get Options for Newton Optimization

Description

Use this function to get optimization options in estim.bin or search.bin functions.

Usage

get.options.newton(
  maxIterations = 100,
  functionTol = 1e-04,
  gradientTol = 0,
  useLineSearch = TRUE
)

Value

A list with the given options.

Arguments

maxIterations

An integer representing the maximum number of iterations.

functionTol

A small value used to test the convergence of the objective function.

gradientTol

A small value used to test the convergence of the gradient.

useLineSearch

If TRUE, line search is used.