ldt.estim.varma ObjectThis function extracts predicted mean and its variance from an ldt.estim.varma object.
new data must be provided while estimating the model.
# S3 method for ldt.estim.varma
predict(object, actualCount = 0, startFrequency = NULL, ...)An object of class ldt.varma.prediction, which is a list with predicted means and (if available) variances.
An object of class ldt.estim.varma
Number of actual observations to be included in the result.
Frequency of the first observation used in the estimation.
This is object of class ldtf.
Additional arguments.
If estimation data undergoes a Box-Cox transformation, the resulting values will not be transformed accordingly.