Learn R Programming

ldt (version 0.5.3)

print.ldt.search: Prints an ldt.search object

Description

Prints the main results in an ldt.search object. This includes information about the first best models and significant coefficients.

Usage

# S3 method for ldt.search
print(x, ...)

Value

This function has no output.

Arguments

x

An object of class ldt.search

...

Additional arguments

Details

An ldt.search object is an output from one of the search.? functions (see search.sur, search.varma, or search.bin).