Learn R Programming

ldt (version 0.5.3)

s.metric.from.weight: Convert a Weight to Metric

Description

This function converts a weight to its metric equivalent.

Usage

s.metric.from.weight(value, metricName, minValue = 0)

Value

A numeric value representing the converted weight.

Arguments

value

Numeric value of the weight.

metricName

Character string specifying the name of the metric. See get.search.metrics function for the list of available options.

minValue

A minimum value used in exponential weight formula.

Details

See s.weight.from.metric and get.search.metrics for more details.

Note that the main purpose of exporting this statistics helper method is to show the inner calculations of the package.

See Also

s.weight.from.metric

Examples

Run this code
weight <- s.weight.from.metric(-3.4, "sic")
metric <- s.metric.from.weight(weight, "sic")

Run the code above in your browser using DataLab