ldt.search objectUse this function to get the full estimation of the models reported in the output of a search process.
# S3 method for ldt.search
summary(object, test = FALSE, ...)The output replaces the value of object$results with the summary from summary.ldt.search.item.
An ldt.search object.
If TRUE and applicable (e.g., in model estimation), it checks the metrics and throws error for any inconsistencies between the current estimation and the one calculated in the search process (Provided that negative seed is used).
Additional arguments.
An ldt.search object is an output from one of the search.? functions (see search.sur, search.varma, or search.bin).