ldt.search.item objectWhile you can get a summary of an item in a search result, this function is mainly designed to be called from print.ldt.search function. Its main job is to estimate the full model using the reported indices from the search process.
# S3 method for ldt.search.item
summary(object, searchResult = NULL, test = FALSE, ...)If the object contains the indices of endogenous variables of an estimated model, it returns the estimation output. Otherwise, it returns object.
An ldt.search.item object.
Parent list of object, which is an ldt.search object.
If TRUE and applicable (e.g., in model estimation), it checks the metrics and throws error for any inconsistencies between the current estimation and the one calculated in the search process.
Additional arguments.
An ldt.search.item object is a member of ldt.search object.
An ldt.search object is an output from one of the search.? functions (see search.sur, search.varma, or search.bin).