Use this function to get optimization options in estim.bin or search.bin functions.
get.options.newton(
maxIterations = 100,
functionTol = 1e-04,
gradientTol = 0,
useLineSearch = TRUE
)A list with the given options.
An integer representing the maximum number of iterations.
A small value used to test the convergence of the objective function.
A small value used to test the convergence of the gradient.
If TRUE, line search is used.