predict.ldt.estim: Extract Prediction Results
Description
This function extracts predicted mean and its variance from an ldt.estim object.
new data must be provided while estimating the model.
Usage
# S3 method for ldt.estim
predict(object, ...)
Value
A list containing the predicted (projected) means and variances.
Arguments
- object
An object of class ldt.estim
- ...
Additional arguments.