powered by
This function converts a weight to its metric equivalent.
s.metric.from.weight(value, metricName, minValue = 0)
A numeric value representing the converted weight.
Numeric value of the weight.
Character string specifying the name of the metric. See get.search.metrics function for the list of available options.
get.search.metrics
A minimum value used in exponential weight formula.
See s.weight.from.metric and get.search.metrics for more details.
Note that the main purpose of exporting this statistics helper method is to show the inner calculations of the package.
s.weight.from.metric
weight <- s.weight.from.metric(-3.4, "sic") metric <- s.metric.from.weight(weight, "sic")
Run the code above in your browser using DataLab