A numeric value representing the converted metric.
Arguments
value
Numeric value of the metric.
metricName
Character string specifying the name of the metric.
See get.search.metrics function for the list of available options.
minValue
A minimum value to be used for metrics with exponential weight formula.
Details
Given a collection of models for the data, a metric is not
generally a metric of the relative quality of a model. This function
converts the value of a metric to such a number.
see get.search.metrics for more details.
The main purpose of exporting this statistics helper method is to show the inner calculations of the package.